==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/test-infra/camel-test-infra-milvus/src/main/java/org/apache/camel/test/infra/milvus/services/MilvusRemoteInfraService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.milvus.services;

import org.apache.camel.test.infra.milvus.common.MilvusProperties;

public class MilvusRemoteInfraService implements MilvusInfraService {

    @Override
    public void registerProperties() {
        // NO-OP
    }

    @Override
    public void initialize() {
        registerProperties();
    }

    @Override
    public void shutdown() {
        // NO-OP
    }

    @Override
    public String getMilvusEndpointUrl() {
        return System.getProperty(MilvusProperties.MILVUS_ENDPOINT_URL);
    }

    @Override
    public String getMilvusHost() {
        return System.getProperty(MilvusProperties.MILVUS_ENDPOINT_HOST);
    }

    @Override
    public int getMilvusPort() {
        return Integer.parseInt(System.getProperty(MilvusProperties.MILVUS_ENDPOINT_PORT));
    }
}

==> apache-camel-4.14.3-src.zip: apache-camel-4.14.3/test-infra/camel-test-infra-milvus/src/main/java/org/apache/camel/test/infra/milvus/services/MilvusRemoteInfraService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.milvus.services;

import org.apache.camel.test.infra.milvus.common.MilvusProperties;

public class MilvusRemoteInfraService implements MilvusInfraService {

    @Override
    public void registerProperties() {
        // NO-OP
    }

    @Override
    public void initialize() {
        registerProperties();
    }

    @Override
    public void shutdown() {
        // NO-OP
    }

    @Override
    public String getMilvusEndpointUrl() {
        return System.getProperty(MilvusProperties.MILVUS_ENDPOINT_URL);
    }

    @Override
    public String host() {
        return System.getProperty(MilvusProperties.MILVUS_ENDPOINT_HOST);
    }

    @Override
    public int port() {
        return Integer.parseInt(System.getProperty(MilvusProperties.MILVUS_ENDPOINT_PORT));
    }
}
